@@ -966,10 +966,13 @@ type ChartPrepareOptions struct {
 	SkipDeps      bool
 	SkipResolve   bool
 	SkipCleanup   bool
-	IncludeCRDs   *bool
-	Wait          bool
-	WaitForJobs   bool
-	OutputDir     string
+	// Validate is a helm-3-only option. When it is set to true, it configures chartify to pass --validate to helm-template run by it.
+	// It's required when one of your chart relies on Capabilities.APIVersions in a template
+	Validate    bool
+	IncludeCRDs *bool
+	Wait        bool
+	WaitForJobs bool
+	OutputDir   string
 }
 
 type chartPrepareResult struct {
@@ -1142,9 +1145,10 @@ func (st *HelmState) PrepareCharts(helm helmexec.Interface, dir string, concurre
 					if opts.IncludeCRDs != nil {
 						includeCRDs = *opts.IncludeCRDs
 					}
-
 					chartifyOpts.IncludeCRDs = includeCRDs
 
+					chartifyOpts.Validate = opts.Validate
+
 					out, err := c.Chartify(release.Name, chartPath, chartify.WithChartifyOpts(chartifyOpts))
 					if err != nil {
 						results <- &chartPrepareResult{err: err}
@@ -1469,7 +1473,6 @@ func (st *HelmState) WriteReleasesValues(helm helmexec.Interface, additionalValu
 			if _, err := os.Stat(valfile); os.IsNotExist(err) {
 				return []error{err}
 			}
-			generatedFiles = append(generatedFiles, valfile)
 		}
 
 		outputValuesFile, err := st.GenerateOutputFilePath(release, opts.OutputFileTemplate)
@@ -1485,7 +1488,7 @@ func (st *HelmState) WriteReleasesValues(helm helmexec.Interface, additionalValu
 
 		merged := map[string]interface{}{}
 
-		for _, f := range generatedFiles {
+		for _, f := range append(generatedFiles, additionalValues...) {
 			src := map[string]interface{}{}
 
 			srcBytes, err := st.readFile(f)
