@@ -883,16 +883,17 @@ func TestHelmState_SyncRepos(t *testing.T) {
 			name: "normal repository",
 			repos: []RepositorySpec{
 				{
-					Name:     "name",
-					URL:      "http://example.com/",
-					CertFile: "",
-					KeyFile:  "",
-					Username: "",
-					Password: "",
+					Name:            "name",
+					URL:             "http://example.com/",
+					CertFile:        "",
+					KeyFile:         "",
+					Username:        "",
+					Password:        "",
+					PassCredentials: "",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "", "", ""},
+			want: []string{"name", "http://example.com/", "", "", "", "", "", "", ""},
 		},
 		{
 			name: "ACR hosted repository",
@@ -903,51 +904,70 @@ func TestHelmState_SyncRepos(t *testing.T) {
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "", "", "", "", "", "", "acr"},
+			want: []string{"name", "", "", "", "", "", "", "acr", ""},
 		},
 		{
 			name: "repository with cert and key",
 			repos: []RepositorySpec{
 				{
-					Name:     "name",
-					URL:      "http://example.com/",
-					CertFile: "certfile",
-					KeyFile:  "keyfile",
-					Username: "",
-					Password: "",
+					Name:            "name",
+					URL:             "http://example.com/",
+					CertFile:        "certfile",
+					KeyFile:         "keyfile",
+					Username:        "",
+					Password:        "",
+					PassCredentials: "",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "certfile", "keyfile", "", "", ""},
+			want: []string{"name", "http://example.com/", "", "certfile", "keyfile", "", "", "", ""},
 		},
 		{
 			name: "repository with ca file",
 			repos: []RepositorySpec{
 				{
-					Name:     "name",
-					URL:      "http://example.com/",
-					CaFile:   "cafile",
-					Username: "",
-					Password: "",
+					Name:            "name",
+					URL:             "http://example.com/",
+					CaFile:          "cafile",
+					Username:        "",
+					Password:        "",
+					PassCredentials: "",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "cafile", "", "", "", "", ""},
+			want: []string{"name", "http://example.com/", "cafile", "", "", "", "", "", ""},
 		},
 		{
 			name: "repository with username and password",
 			repos: []RepositorySpec{
 				{
-					Name:     "name",
-					URL:      "http://example.com/",
-					CertFile: "",
-					KeyFile:  "",
-					Username: "example_user",
-					Password: "example_password",
+					Name:            "name",
+					URL:             "http://example.com/",
+					CertFile:        "",
+					KeyFile:         "",
+					Username:        "example_user",
+					Password:        "example_password",
+					PassCredentials: "",
 				},
 			},
 			helm: &exectest.Helm{},
-			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", ""},
+			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", ""},
+		},
+		{
+			name: "repository with username and password and pass-credentials",
+			repos: []RepositorySpec{
+				{
+					Name:            "name",
+					URL:             "http://example.com/",
+					CertFile:        "",
+					KeyFile:         "",
+					Username:        "example_user",
+					Password:        "example_password",
+					PassCredentials: "true",
+				},
+			},
+			helm: &exectest.Helm{},
+			want: []string{"name", "http://example.com/", "", "", "", "example_user", "example_password", "", "true"},
 		},
 	}
 	for i := range tests {
